@@ -56,7 +56,15 @@ class SequentialEngine(EngineBase):
     Trains and scores pipelines locally and sequentially.
     """
 
-    def submit_evaluation_job(self, automl_config, pipeline, X, y):
+    def submit_evaluation_job(
+        self,
+        automl_config,
+        pipeline,
+        X,
+        y,
+        X_holdout=None,
+        y_holdout=None,
+    ):
         """Submit a job to evaluate a pipeline.
 
         Args:
@@ -64,6 +72,8 @@ class SequentialEngine(EngineBase):
             pipeline (pipeline.PipelineBase): Pipeline to evaluate.
             X (pd.DataFrame): Input data for modeling.
             y (pd.Series): Target data for modeling.
+            X_holdout (pd.Series): Holdout input data for holdout scoring.
+            y_holdout (pd.Series): Holdout target data for holdout scoring.
 
         Returns:
             SequentialComputation: Computation result.
@@ -75,6 +85,8 @@ class SequentialEngine(EngineBase):
             automl_config=automl_config,
             X=X,
             y=y,
+            X_holdout=X_holdout,
+            y_holdout=y_holdout,
             logger=logger,
         )
 
