@@ -50,7 +50,7 @@ class TimeSeriesClassificationPipeline(TimeSeriesPipelineBase, ClassificationPip
             ValueError: If the number of unique classes in y are not appropriate for the type of pipeline.
         """
         self.frequency = infer_frequency(X[self.time_index])
-        X = self._drop_time_index(X)
+        X = self._drop_time_index(X, y)
         return super().fit(X, y)
 
     def predict_proba_in_sample(self, X_holdout, y_holdout, X_train, y_train):
@@ -169,8 +169,8 @@ class TimeSeriesClassificationPipeline(TimeSeriesPipelineBase, ClassificationPip
         """
         X, y = self._convert_to_woodwork(X, y)
         X_train, y_train = self._convert_to_woodwork(X_train, y_train)
-        X = self._drop_time_index(X)
-        X_train = self._drop_time_index(X_train)
+        X = self._drop_time_index(X, y)
+        X_train = self._drop_time_index(X_train, y_train)
         objectives = self.create_objectives(objectives)
         y_predicted, y_predicted_proba = self._compute_predictions(
             X,
