@@ -39,14 +39,14 @@ def test_problem_types():
 
 
 def test_model_instance(ts_data):
-    X, y = ts_data
+    X, _, y = ts_data()
     clf = ARIMARegressor()
     fitted = clf.fit(X, y)
     assert isinstance(fitted, ARIMARegressor)
 
 
 def test_fit_ts_without_y(ts_data):
-    X, y = ts_data
+    X, _, _ = ts_data()
 
     clf = ARIMARegressor()
     with pytest.raises(ValueError, match="ARIMA Regressor requires y as input."):
@@ -70,9 +70,9 @@ def test_remove_datetime(
     train_none,
     datetime_feature,
     no_features,
-    get_ts_X_y,
+    ts_data,
 ):
-    X_train, _, y_train = get_ts_X_y(
+    X_train, _, y_train = ts_data(
         train_features_index_dt,
         train_target_index_dt,
         train_none,
@@ -109,8 +109,8 @@ def test_remove_datetime(
     assert not isinstance(y_train_no_dt.index, pd.DatetimeIndex)
 
 
-def test_match_indices(get_ts_X_y):
-    X_train, _, y_train = get_ts_X_y(
+def test_match_indices(ts_data):
+    X_train, _, y_train = ts_data(
         train_features_index_dt=False,
         train_target_index_dt=False,
         train_none=False,
@@ -126,10 +126,10 @@ def test_match_indices(get_ts_X_y):
     assert X_.index.equals(y_.index)
 
 
-def test_set_forecast(get_ts_X_y):
+def test_set_forecast(ts_data):
     from sktime.forecasting.base import ForecastingHorizon
 
-    _, X_test, _ = get_ts_X_y(
+    _, X_test, _ = ts_data(
         train_features_index_dt=False,
         train_target_index_dt=False,
         train_none=False,
@@ -185,7 +185,7 @@ def test_get_sp():
 
 
 def test_feature_importance(ts_data):
-    X, y = ts_data
+    X, _, y = ts_data()
     clf = ARIMARegressor()
     with patch.object(clf, "_component_obj"):
         clf.fit(X, y)
@@ -209,12 +209,12 @@ def test_fit_predict(
     no_features,
     datetime_feature,
     test_features_index_dt,
-    get_ts_X_y,
+    ts_data,
 ):
     from sktime.forecasting.arima import AutoARIMA
     from sktime.forecasting.base import ForecastingHorizon
 
-    X_train, X_test, y_train = get_ts_X_y(
+    X_train, X_test, y_train = ts_data(
         train_features_index_dt,
         train_target_index_dt,
         train_none,
@@ -257,11 +257,11 @@ def test_fit_predict_sk_failure(
     no_features,
     datetime_feature,
     test_features_index_dt,
-    get_ts_X_y,
+    ts_data,
 ):
     from sktime.forecasting.arima import AutoARIMA
 
-    X_train, X_test, y_train = get_ts_X_y(
+    X_train, X_test, y_train = ts_data(
         train_features_index_dt,
         train_target_index_dt,
         train_none,
@@ -387,9 +387,7 @@ def test_arima_boolean_features_no_error():
 @patch("sktime.forecasting.arima.AutoARIMA.fit")
 @patch("sktime.forecasting.arima.AutoARIMA.predict")
 def test_arima_regressor_respects_use_covariates(mock_predict, mock_fit, ts_data):
-    X, y = ts_data
-    X_train, y_train = X.iloc[:25], y.iloc[:25]
-    X_test, _ = X.iloc[25:], y.iloc[25:]
+    X_train, X_test, y_train = ts_data()
     clf = ARIMARegressor(use_covariates=False)
 
     clf.fit(X_train, y_train)
