@@ -43,7 +43,8 @@ def test_exceptions():
     ):
         force_plot(None, None, None, None)
     with pytest.raises(
-        TypeError, match="rows_to_explain should only contain integers!"
+        TypeError,
+        match="rows_to_explain should only contain integers!",
     ):
         force_plot(
             pipeline=None,
@@ -56,7 +57,8 @@ def test_exceptions():
 @patch("evalml.model_understanding.force_plots.jupyter_check")
 @patch("evalml.model_understanding.force_plots.initjs")
 @pytest.mark.parametrize(
-    "rows_to_explain, just_data", product([[0], [0, 1, 2, 3, 4]], [False, True])
+    "rows_to_explain, just_data",
+    product([[0], [0, 1, 2, 3, 4]], [False, True]),
 )
 def test_force_plot_binary(
     initjs,
@@ -68,7 +70,7 @@ def test_force_plot_binary(
     X, y = breast_cancer_local
 
     pipeline = BinaryClassificationPipeline(
-        component_graph=["Simple Imputer", "Random Forest Classifier"]
+        component_graph=["Simple Imputer", "Random Forest Classifier"],
     )
     pipeline.fit(X, y)
 
@@ -115,7 +117,7 @@ def test_force_plot_binary(
         assert set(class_labels) == expected_class_labels
         for class_label in expected_class_labels:
             assert {"expected_value", "feature_names", "shap_values"}.issubset(
-                set(result[class_label].keys())
+                set(result[class_label].keys()),
             )
 
     if not just_data:
@@ -131,13 +133,14 @@ def test_force_plot_binary(
 
 
 @pytest.mark.parametrize(
-    "rows_to_explain, just_data", product([[0], [0, 1, 2, 3, 4]], [False, True])
+    "rows_to_explain, just_data",
+    product([[0], [0, 1, 2, 3, 4]], [False, True]),
 )
 def test_force_plot_multiclass(rows_to_explain, just_data, wine_local):
     X, y = wine_local
 
     pipeline = MulticlassClassificationPipeline(
-        component_graph=["Simple Imputer", "Random Forest Classifier"]
+        component_graph=["Simple Imputer", "Random Forest Classifier"],
     )
     pipeline.fit(X, y)
 
@@ -163,7 +166,7 @@ def test_force_plot_multiclass(rows_to_explain, just_data, wine_local):
         assert set(class_labels) == expected_class_labels
         for class_label in expected_class_labels:
             assert {"expected_value", "feature_names", "shap_values"}.issubset(
-                set(result[class_label].keys())
+                set(result[class_label].keys()),
             )
 
     if not just_data:
@@ -179,7 +182,8 @@ def test_force_plot_multiclass(rows_to_explain, just_data, wine_local):
 
 
 @pytest.mark.parametrize(
-    "rows_to_explain, just_data", product([[0], [0, 1, 2, 3, 4]], [False, True])
+    "rows_to_explain, just_data",
+    product([[0], [0, 1, 2, 3, 4]], [False, True]),
 )
 def test_force_plot_regression(rows_to_explain, just_data, X_y_regression):
     X, y = X_y_regression
@@ -187,7 +191,7 @@ def test_force_plot_regression(rows_to_explain, just_data, X_y_regression):
     y = pd.Series(y)
 
     pipeline = RegressionPipeline(
-        component_graph=["Simple Imputer", "LightGBM Regressor"]
+        component_graph=["Simple Imputer", "LightGBM Regressor"],
     )
     pipeline.fit(X, y)
 
@@ -210,14 +214,15 @@ def test_force_plot_regression(rows_to_explain, just_data, X_y_regression):
         assert len(class_labels) == 1
         assert "regression" in class_labels
         assert {"expected_value", "feature_names", "shap_values"}.issubset(
-            set(result["regression"].keys())
+            set(result["regression"].keys()),
         )
 
     if not just_data:
         # Should have a force plot for each row result.
         for result in results:
             assert isinstance(
-                result["regression"]["plot"], shap.plots._force.AdditiveForceVisualizer
+                result["regression"]["plot"],
+                shap.plots._force.AdditiveForceVisualizer,
             )
         validate_plot_feature_values(results, X)
 
@@ -274,7 +279,7 @@ def test_categories_aggregated_text(pipeline_class, estimator, fraud_100):
         component_graph,
         parameters={
             "Select Columns Transformer": {
-                "columns": ["amount", "provider", "currency", "datetime"]
+                "columns": ["amount", "provider", "currency", "datetime"],
             },
             estimator: {"n_jobs": 1},
         },
